searchNodes=[{"type":"behaviour","title":"RemotePersistentTerm","doc":"Fetch data from a remote source and store it in a persistent_term . Can be configured to periodically check for updates. use this module to define a GenServer that will manage the state of your fetcher and keep your term up to date.","ref":"RemotePersistentTerm.html"},{"type":"macro","title":"RemotePersistentTerm.__using__/1","doc":"Define a GenServer that will manage this specific persistent_term. Example: This will define a GenServer that should be placed in your supervision tree. The GenServer will check for a new version of s3://my-bucket/my-object every 12 hours and store it in a persistent_term. Define the module: defmodule MyRemotePterm do use RemotePersistentTerm end In your supervision tree: { MyRemotePterm , [ fetcher_mod : RemotePersistentTerm.Fetcher.S3 , fetcher_opts : [ bucket : &quot;my-bucket&quot; , key : &quot;my-object&quot; ] , refresh_interval : :timer . hours ( 12 ) ] } Options: :fetcher_mod - Required. The implementation of the RemotePersistentTerm.Fetcher behaviour which should be used. Either one of the built in modules or a custom module. The default value is RemotePersistentTerm.Fetcher.S3 . :fetcher_opts ( keyword/0 ) - Configuration options for the chosen fetcher implementation. See your chosen implementation module for details.&quot; The default value is [] . :refresh_interval - How often the term should be updated in milliseconds. To disable automatic refresh, set the value to nil . Note: updating persistent_terms can be very expensive. See the docs for more info.&quot; The default value is nil . :lazy_init? ( boolean/0 ) - If true, the GenServer will start up immediately and the term will be populated in a handle_continue/2 . This means that there will be a period while the remote term is being downloaded and no data is available. If this is not acceptable, set this value to false (the default). The default value is false . :alias ( atom/0 ) - An alias for this term. A value will be generated based on the module name if no value is provided. Used for Telemetry events.","ref":"RemotePersistentTerm.html#__using__/1"},{"type":"callback","title":"RemotePersistentTerm.deserialize/1","doc":"Deserializes the remote term, before storing it. Overridable. Commonly the remote term is an ETF encoded binary. In this case you will likely want to override this callback with something like: def deserialize ( binary ) do { :ok , :erlang . binary_to_term ( binary ) } rescue _ -&gt; { :error , &quot;got invalid ETF&quot; } end","ref":"RemotePersistentTerm.html#c:deserialize/1"},{"type":"callback","title":"RemotePersistentTerm.get/0","doc":"Retrieve the currently stored term. Overridable.","ref":"RemotePersistentTerm.html#c:get/0"},{"type":"callback","title":"RemotePersistentTerm.put/1","doc":"Update the persistent_term. Overridable. This is called after deserialize/1 .","ref":"RemotePersistentTerm.html#c:put/1"},{"type":"function","title":"RemotePersistentTerm.schedule_update/2","doc":"Schedule an update of the persistent_term.","ref":"RemotePersistentTerm.html#schedule_update/2"},{"type":"type","title":"RemotePersistentTerm.t/0","doc":"","ref":"RemotePersistentTerm.html#t:t/0"},{"type":"behaviour","title":"RemotePersistentTerm.Fetcher","doc":"A generic behaviour for a Fetcher module which is responsible for checking the latest version available in the remote source and downloading it.","ref":"RemotePersistentTerm.Fetcher.html"},{"type":"callback","title":"RemotePersistentTerm.Fetcher.current_version/1","doc":"Check the current version of the remote term. Used to avoid downloading the same term multiple times.","ref":"RemotePersistentTerm.Fetcher.html#c:current_version/1"},{"type":"callback","title":"RemotePersistentTerm.Fetcher.download/1","doc":"Download the term from the remote source.","ref":"RemotePersistentTerm.Fetcher.html#c:download/1"},{"type":"callback","title":"RemotePersistentTerm.Fetcher.init/1","doc":"Initialize the implementation specific state of the Fetcher.","ref":"RemotePersistentTerm.Fetcher.html#c:init/1"},{"type":"type","title":"RemotePersistentTerm.Fetcher.opts/0","doc":"","ref":"RemotePersistentTerm.Fetcher.html#t:opts/0"},{"type":"type","title":"RemotePersistentTerm.Fetcher.state/0","doc":"Implementation specific state.","ref":"RemotePersistentTerm.Fetcher.html#t:state/0"},{"type":"type","title":"RemotePersistentTerm.Fetcher.version/0","doc":"","ref":"RemotePersistentTerm.Fetcher.html#t:version/0"},{"type":"module","title":"RemotePersistentTerm.Fetcher.Http","doc":"A Fetcher implementation for HTTP.","ref":"RemotePersistentTerm.Fetcher.Http.html"},{"type":"function","title":"RemotePersistentTerm.Fetcher.Http.init/1","doc":"Initialize a HTTP Fetcher. Options: :url ( String.t/0 ) - Required. The url from which the remote term is downloaded. :http_cache ( keyword/0 ) - Configuration options for the HTTP Caching spec. The default value is [] . :enabled? ( boolean/0 ) - If true, the HTTP Caching spec will be used to schedule the next download and :refresh_interval can be omitted. The default value is false . :min_refresh_interval_ms ( non_neg_integer/0 ) - The minimum time in milliseconds between refreshes. This value is only used if http_cache.enabled? is true. The default value is 30000 .","ref":"RemotePersistentTerm.Fetcher.Http.html#init/1"},{"type":"type","title":"RemotePersistentTerm.Fetcher.Http.t/0","doc":"","ref":"RemotePersistentTerm.Fetcher.Http.html#t:t/0"},{"type":"module","title":"RemotePersistentTerm.Fetcher.Http.Cache","doc":"A module to assist in following the HTTP Caching spec. See more: https://developer.mozilla.org/en-US/docs/Web/HTTP/Caching","ref":"RemotePersistentTerm.Fetcher.Http.Cache.html"},{"type":"function","title":"RemotePersistentTerm.Fetcher.Http.Cache.refresh_interval/1","doc":"Calculates the refresh interval from the cache-control and age headers. Caching directives are case-insensitive. Multiple directives are permitted and must be comma-separated. Refresh interval is in milliseconds.","ref":"RemotePersistentTerm.Fetcher.Http.Cache.html#refresh_interval/1"},{"type":"module","title":"RemotePersistentTerm.Fetcher.S3","doc":"A Fetcher implementation for AWS S3.","ref":"RemotePersistentTerm.Fetcher.S3.html"},{"type":"function","title":"RemotePersistentTerm.Fetcher.S3.init/1","doc":"Initialize an S3 Fetcher. Requires AWS credentials to be provided via env vars. The following vars must be set to the appropriate values: AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_DEFAULT_REGION Options: :bucket ( String.t/0 ) - Required. The s3 bucket in which the remote term is stored. :key ( String.t/0 ) - Required. The key within the s3 bucket which refers to the remote term.","ref":"RemotePersistentTerm.Fetcher.S3.html#init/1"},{"type":"type","title":"RemotePersistentTerm.Fetcher.S3.t/0","doc":"","ref":"RemotePersistentTerm.Fetcher.S3.html#t:t/0"},{"type":"module","title":"RemotePersistentTerm.Fetcher.Static","doc":"A macro to help define a valid RemotePersistentTerm.Fetcher which always returns some hardcoded static data. Mostly intended for testing purposes. Example: defmodule MyStaticFetcher do use RemotePersistentTerm.Fetcher.Static , data : %{ my : :data } end","ref":"RemotePersistentTerm.Fetcher.Static.html"}]